@@ -23,7 +23,7 @@ end
 
 module SDL
 
-  VERSION = "0.9.1"
+  VERSION = "0.9.3"
 
   class PixelFormat
 
@@ -51,6 +51,19 @@ module SDL
 	rotateScaledSurface(angle,1.0,bgcolor)
       end
     end
+
+    
+    def copyRect(x,y,w,h)
+      flagbase=SDL::SWSURFACE|SDL::HWSURFACE|SDL::SRCCOLORKEY|SDL::SRCALPHA
+      new_surface=Surface.new(flagbase&self.flags,w,h,self)
+      SDL.blitSurface(self,x,y,w,h,new_surface,0,0)
+      new_surface.setColorKey(self.flags & (SDL::SRCCOLORKEY|SDL::RLEACCEL),
+                              self.colorkey )
+      new_surface.setAlpha(self.flags & (SDL::SRCALPHA|SDL::RLEACCEL),
+                           self.alpha )
+      return new_surface
+    end
+    
   end
 
   def color2int(color,format)
@@ -140,11 +153,12 @@ module SDL
 
   if defined?(transform) then
     def transformBlit(src,dst,angle,xscale,yscale,px,py,qx,qy,flags)
-      colorkey = src.colorkey
-      transformed = src.transformSurface( colorkey, angle,
+      transformed = src.transformSurface( src.colorkey, angle,
 					 xscale, yscale, flags )
       transformed.setColorKey( src.flags & (SDL::SRCCOLORKEY|SDL::RLEACCEL),
-			      colorkey )
+			      src.colorkey )
+      transformed.setAlpha( src.flags & (SDL::SRCALPHA|SDL::RLEACCEL),
+			    src.alpha )
       rad = Math::PI*angle/180.0
       x = px - src.w/2.0 ; y = py - src.h/2.0
       x *= xscale ; y *= yscale
