@@ -1,7 +1,7 @@
 /*
   Ruby/SDL   Ruby extension library for SDL
 
-  Copyright (C) 2001,2002 Ohbayashi Ippei
+  Copyright (C) 2001-2004 Ohbayashi Ippei
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -309,20 +309,6 @@ static void defineConstForEvent()
 
 }
 
-static VALUE sdl_event2_enableUNICODE(VALUE class)
-{
-  SDL_EnableUNICODE(1);
-  return Qnil;
-}
-static VALUE sdl_event2_disableUNICODE(VALUE class)
-{
-  SDL_EnableUNICODE(0);
-  return Qnil;
-}
-static VALUE sdl_event2_is_enableUNICODE(VALUE class)
-{
-  return BOOL(SDL_EnableUNICODE(-1));
-}
 
 void init_event()
 {
