@@ -1,7 +1,7 @@
 /*
   Ruby/SDL   Ruby extension library for SDL
 
-  Copyright (C) 2001,2002 Ohbayashi Ippei
+  Copyright (C) 2001-2004 Ohbayashi Ippei
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,6 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   */
-/* rubysdl.c -- SDL(Simple Directmedia Layer)
- */
 
 #define DEF_GLOBAL
 #include "rubysdl.h"
@@ -51,8 +49,10 @@ void init_joystick();
 void init_cdrom();
 void init_time();
 void init_wm();
+void init_kanji(void);
 #ifdef HAVE_SDL_TTF
 void init_ttf();
+void quit_ttf();
 #endif
 #ifdef HAVE_SDL_MIXER
 void  init_mixer();
@@ -62,18 +62,29 @@ void quit_mixer();
 void init_smpeg();
 #endif
 
+#ifdef HAVE_SDLSKK
+void init_sdlskk();
+#endif
+
 static void sdl_quit();
 static VALUE sdl_init(VALUE obj,VALUE flags)
 {
   Uint32 flag;
   
-  rb_secure(1);
+  rb_secure(4);
   flag= NUM2UINT(flags);
   if( SDL_Init(flag) < 0 )
     rb_raise(eSDLError,"Couldn't initialize SDL: %s",SDL_GetError());
   return Qnil;
 }
 
+static VALUE sdl_initSubSystem(VALUE obj,VALUE flags)
+{
+  if( SDL_InitSubSystem(NUM2UINT(flags)) < 0 )
+    rb_raise(eSDLError,"Couldn't initialize SDL subsystem: %s",SDL_GetError());
+  return Qnil;
+}
+
 static VALUE sdl_wasInit(VALUE mod,VALUE flags)
 {
   return UINT2NUM( SDL_WasInit(NUM2UINT(flags)) );
@@ -116,9 +127,11 @@ void Init_sdl()
   eSDLError = rb_define_class_under(mSDL,"Error",rb_eStandardError);
   rb_define_module_function(mSDL,"init",sdl_init,1);
   rb_define_module_function(mSDL,"initedSystem",sdl_wasInit,1);
+  rb_define_module_function(mSDL,"initSubSystem",sdl_initSubSystem,1);
   
   defineConst();
-  
+
+
   init_video();
 #ifdef HAVE_SGE
   init_sge_video();
@@ -144,6 +157,7 @@ void Init_sdl()
   init_cdrom();
   init_time();
   init_wm();
+  init_kanji();
 #ifdef HAVE_SDL_TTF
   init_ttf();
 #endif
