@@ -10,14 +10,11 @@ image=SDL::Surface.loadBMP 'cursor.bmp'
 SDL::Mouse.setCursor image,image[0,0],image[1,1],image[7,0],543
 
 
-event=SDL::Event.new
-
-while true 
-  if  event.poll != 0 then
-    if event.type==SDL::Event::QUIT then
-      break
-    end
-    if event.type==SDL::Event::KEYDOWN then
+while true
+  
+  while event = SDL::Event2.poll
+    case event
+    when SDL::Event2::KeyDown, SDL::Event2::Quit
       exit
     end
   end
