@@ -1,11 +1,16 @@
-
+#
+# Usage:
+#    ruby joy2.rb [n]
+#      n: if given, use n'th joystick
+#           if not given, show all connected joystick
+# 
 require 'sdl'
 
 White = [255,255,255]
 
 def print_joystick_info
   for i in 0..SDL::Joystick.num-1
-    print i,":",SDL::Joystick.name(0),"\n"
+    print i,":",SDL::Joystick.indexName(0),"\n"
   end
 end
 
@@ -20,13 +25,20 @@ def display_button_state ( screen, joy )
 end
 
 def display_hat_state ( screen, joy )
-  # display the state of only first hat
-  
+  # display the state of only first hat  
+  if joy.numHats > 0 then
+    x = y = 0
+    x = 1 if  ( joy.hat(0) & SDL::Joystick::HAT_RIGHT ) != 0
+    x = -1 if ( joy.hat(0) & SDL::Joystick::HAT_LEFT ) != 0
+    y = 1 if ( joy.hat(0) & SDL::Joystick::HAT_DOWN ) != 0
+    y = -1 if ( joy.hat(0) & SDL::Joystick::HAT_UP ) != 0
+    screen.fillRect( 450 + x*40, 200 + y*40, 10, 10, White )
+  end
 end
 
 def display_axis_state ( screen, joy )
   for i in 0..joy.numAxes-1
-    screen.fillRect( i*30+130, joy.axis(i)*150/32768, 20, 20, White )
+    screen.fillRect( i*30+130, joy.axis(i)*100/32768+200, 20, 20, White )
   end
 end
 
@@ -50,16 +62,13 @@ if SDL::Joystick.num < joynum then
   exit
 end
 
-joy=SDL::Joystick.open(0)
+joy=SDL::Joystick.open(joynum)
 
-event=SDL::Event.new
+while true
 
-while true 
-  if  event.poll != 0 then
-    if event.type==SDL::Event::QUIT then
-      break
-    end
-    if event.type==SDL::Event::KEYDOWN then
+  while event = SDL::Event2.poll
+    case event
+    when SDL::Event2::KeyDown, SDL::Event2::Quit
       exit
     end
   end
