@@ -1,9 +1,7 @@
 require 'sdl'
-#require 'opengl'
 
 SDL.init( SDL::INIT_VIDEO )
 screen = SDL::setVideoMode(640,480,16,SDL::SWSURFACE)
-#screen.setClipRect( 50,50,400,200 )
 SDL::WM::setCaption('testsprite.rb','testsprite.rb icon')
 image = SDL::Surface.loadBMP("icon.bmp")
 image.setColorKey( SDL::SRCCOLORKEY ,0)
@@ -51,14 +49,10 @@ for i in 1..100
 end
 
 
-event=SDL::Event.new
-
-while true 
-  if  event.poll != 0 then
-    if event.type==SDL::Event::QUIT then
-      break
-    end
-    if event.type==SDL::Event::KEYDOWN then
+while true
+  while event = SDL::Event2.poll
+    case event
+    when SDL::Event2::KeyDown, SDL::Event2::Quit
       exit
     end
   end
@@ -69,7 +63,6 @@ while true
     i.draw(screen)
   }
   screen.updateRect(0,0,0,0)
-  ObjectSpace.garbage_collect
 end
 
 
